@@ -1,7 +1,7 @@
 /*
   Copyright (C) 2010 Klaralvdalens Datakonsult AB, a KDAB Group company, info@kdab.com
   Copyright (c) 2010 Leo Franchi <lfranchi@kde.org>
-  Copyright (c) 2017 Laurent Montel <montel@kde.org>
+  Copyright (C) 2017-2018 Laurent Montel <montel@kde.org>
 
   This library is free software; you can redistribute it and/or modify it
   under the terms of the GNU Library General Public License as published by
@@ -24,8 +24,7 @@
 
 #include <QObject>
 #include <kmime/kmime_message.h>
-namespace KIdentityManagement
-{
+namespace KIdentityManagement {
 class IdentityManager;
 }
 class MessageFactoryTest : public QObject
@@ -64,7 +63,7 @@ private:
     KMime::Message::Ptr loadMessageFromFile(const QString &filename);
     KMime::Message::Ptr createPlainTestMessageWithMultiEmails();
     KMime::Message::Ptr loadMessage(const QString &filename);
-    KIdentityManagement::IdentityManager *mIdentMan;
+    KIdentityManagement::IdentityManager *mIdentMan = nullptr;
 };
 
 #endif
