@@ -86,12 +86,12 @@ public:
     /**
     * Returns the type of this item. The Type can be set only in the constructor.
     */
-    Type type() const;
+    Q_REQUIRED_RESULT Type type() const;
 
     /**
     * The initial expand status we have to honor when attacching to the viewable root.
     */
-    InitialExpandStatus initialExpandStatus() const;
+    Q_REQUIRED_RESULT InitialExpandStatus initialExpandStatus() const;
 
     /**
     * Set the initial expand status we have to honor when attacching to the viewable root.
@@ -101,13 +101,13 @@ public:
     /**
     * Is this item attached to the viewable root ?
     */
-    bool isViewable() const;
+    Q_REQUIRED_RESULT bool isViewable() const;
 
     /**
     * Return true if Item pointed by it is an ancestor of this item (that is,
     * if it is its parent, parent of its parent, parent of its parent of its parent etc...
     */
-    bool hasAncestor(const Item *it) const;
+    Q_REQUIRED_RESULT bool hasAncestor(const Item *it) const;
 
     /**
     * Makes this item viewable, that is, notifies its existence to any listener
@@ -120,46 +120,46 @@ public:
     /**
     * Return the list of child items. May be null.
     */
-    QList< Item * > *childItems() const;
+    Q_REQUIRED_RESULT QList< Item * > *childItems() const;
 
     /**
     * Returns the child item at position idx or 0 if idx is out of the allowable range.
     */
-    Item *childItem(int idx) const;
+    Q_REQUIRED_RESULT Item *childItem(int idx) const;
 
     /**
     * Returns the first child item, if any.
     */
-    Item *firstChildItem() const;
+    Q_REQUIRED_RESULT Item *firstChildItem() const;
 
     /**
     * Returns the item that is visually below the specified child if this item.
     * Note that the returned item may belong to a completely different subtree.
     */
-    Item *itemBelowChild(Item *child);
+    Q_REQUIRED_RESULT Item *itemBelowChild(Item *child);
 
     /**
     * Returns the item that is visually above the specified child if this item.
     * Note that the returned item may belong to a completely different subtree.
     */
-    Item *itemAboveChild(Item *child);
+    Q_REQUIRED_RESULT Item *itemAboveChild(Item *child);
 
     /**
     * Returns the deepest item in the subtree originating at this item.
     */
-    Item *deepestItem();
+    Q_REQUIRED_RESULT Item *deepestItem();
 
     /**
     * Returns the item that is visually below this item in the tree.
     * Note that the returned item may belong to a completely different subtree.
     */
-    Item *itemBelow();
+    Q_REQUIRED_RESULT Item *itemBelow();
 
     /**
     * Returns the item that is visually above this item in the tree.
     * Note that the returned item may belong to a completely different subtree.
     */
-    Item *itemAbove();
+    Q_REQUIRED_RESULT Item *itemAbove();
 
     /**
     * Debug helper. Dumps the structure of this subtree.
@@ -169,12 +169,12 @@ public:
     /**
     * Returns the number of children of this Item.
     */
-    int childItemCount() const;
+    Q_REQUIRED_RESULT int childItemCount() const;
 
     /**
     * Convenience function that returns true if this item has children.
     */
-    bool hasChildren() const;
+    Q_REQUIRED_RESULT bool hasChildren() const;
 
     /**
     * A structure used with MessageList::Item::childItemStats().
@@ -221,7 +221,7 @@ public:
     * Please note that even if this item has a non-zero parent, it can be still non viewable.
     * That is: the topmost parent of this item may be not attached to the viewable root.
     */
-    Item *parent() const;
+    Q_REQUIRED_RESULT Item *parent() const;
 
     /**
     * Sets the parent for this item. You should also take care of inserting
@@ -232,7 +232,7 @@ public:
     /**
     * Returns the topmost parent item that is not a Root item (that is, is a Message or GroupHeader).
     */
-    Item *topmostNonRoot();
+    Q_REQUIRED_RESULT Item *topmostNonRoot();
 
     /**
     * Returns the status associated to this Item.
@@ -247,7 +247,7 @@ public:
     /**
     * Returns a string describing the status e.g: "Read, Forwarded, Important"
     */
-    QString statusDescription() const;
+    Q_REQUIRED_RESULT QString statusDescription() const;
 
     /**
     * Returns the size of this item (size of the Message, mainly)
@@ -263,7 +263,7 @@ public:
     * A string with a text rappresentation of size(). This is computed on-the-fly
     * and not cached.
     */
-    QString formattedSize() const;
+    Q_REQUIRED_RESULT QString formattedSize() const;
 
     /**
     * Returns the date of this item
@@ -279,7 +279,7 @@ public:
     * A string with a text rappresentation of date() obtained via Manager. This is computed on-the-fly
     * and not cached.
     */
-    QString formattedDate() const;
+    Q_REQUIRED_RESULT QString formattedDate() const;
 
     /**
     * Returns the maximum date in the subtree originating from this item.
@@ -296,7 +296,7 @@ public:
     * A string with a text rappresentation of maxDate() obtained via Manager. This is computed on-the-fly
     * and not cached.
     */
-    QString formattedMaxDate() const;
+    Q_REQUIRED_RESULT QString formattedMaxDate() const;
 
     /**
     * Recompute the maximum date from the current children list.
@@ -307,7 +307,7 @@ public:
     /**
     * Returns the sender associated to this item.
     */
-    const QString &sender() const;
+    Q_REQUIRED_RESULT const QString &sender() const;
 
     /**
     * Sets the sender associated to this item.
@@ -317,7 +317,7 @@ public:
     /**
     * Display sender.
     */
-    QString displaySender() const;
+    Q_REQUIRED_RESULT QString displaySender() const;
 
     /**
     * Returns the receiver associated to this item.
@@ -332,7 +332,7 @@ public:
     /**
     * Display receiver.
     */
-    QString displayReceiver() const;
+    Q_REQUIRED_RESULT QString displayReceiver() const;
 
     /**
     * Returns the sender or the receiver, depending on the underlying StorageModel settings.
@@ -342,7 +342,7 @@ public:
     /**
     * Display sender or receiver.
     */
-    QString displaySenderOrReceiver() const;
+    Q_REQUIRED_RESULT QString displaySenderOrReceiver() const;
 
     /**
     * Returns whether sender or receiver is supposed to be displayed.
@@ -367,10 +367,10 @@ public:
     void initialSetup(time_t date, size_t size, const QString &sender, const QString &receiver, bool useReceiver);
 
     void setItemId(qint64 id);
-    qint64 itemId() const;
+    Q_REQUIRED_RESULT qint64 itemId() const;
 
     void setParentCollectionId(qint64 id);
-    qint64 parentCollectionId() const;
+    Q_REQUIRED_RESULT qint64 parentCollectionId() const;
 
     /**
     * This is meant to be called right after the constructor for MessageItem objects.
@@ -382,7 +382,7 @@ public:
     * Appends an Item to this item's child list.
     * The Model is used for beginInsertRows()/endInsertRows() calls.
     */
-    int appendChildItem(Model *model, Item *child);
+    Q_REQUIRED_RESULT int appendChildItem(Model *model, Item *child);
 
     /**
     * Appends a child item without inserting it via the model.
