@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2014-2017 Montel Laurent <montel@kde.org>
+  Copyright (c) 2014-2018 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -24,29 +24,29 @@
 MailSourceViewTextBrowserWidgetTest::MailSourceViewTextBrowserWidgetTest(QObject *parent)
     : QObject(parent)
 {
-
 }
 
 MailSourceViewTextBrowserWidgetTest::~MailSourceViewTextBrowserWidgetTest()
 {
-
 }
 
 void MailSourceViewTextBrowserWidgetTest::shouldHaveDefaultValue()
 {
     MessageViewer::MailSourceViewTextBrowserWidget widget(QStringLiteral("Email"));
 
-    MessageViewer::MailSourceViewTextBrowser *textbrowser = widget.findChild<MessageViewer::MailSourceViewTextBrowser *>(QStringLiteral("textbrowser"));
+    MessageViewer::MailSourceViewTextBrowser *textbrowser
+        = widget.findChild<MessageViewer::MailSourceViewTextBrowser *>(QStringLiteral("textbrowser"));
     QVERIFY(textbrowser);
     QVERIFY(!textbrowser->isHidden());
-    MessageViewer::FindBarSourceView *findbar = widget.findChild<MessageViewer::FindBarSourceView *>(QStringLiteral("findbar"));
+    MessageViewer::FindBarSourceView *findbar
+        = widget.findChild<MessageViewer::FindBarSourceView *>(QStringLiteral("findbar"));
     QVERIFY(findbar);
     QVERIFY(findbar->isHidden());
 
-    KPIMTextEdit::TextToSpeechWidget *texttospeechwidget = widget.findChild<KPIMTextEdit::TextToSpeechWidget *>(QStringLiteral("texttospeech"));
+    KPIMTextEdit::TextToSpeechWidget *texttospeechwidget
+        = widget.findChild<KPIMTextEdit::TextToSpeechWidget *>(QStringLiteral("texttospeech"));
     QVERIFY(texttospeechwidget);
     QVERIFY(texttospeechwidget->isHidden());
-
 }
 
 QTEST_MAIN(MailSourceViewTextBrowserWidgetTest)
