@@ -1,6 +1,6 @@
 /* This file is part of the KDE project
    Copyright (C) 2002 Daniel Molkentin <molkentin@kde.org>
-   Copyright (C) 2013-2017 Laurent Montel <montel@kde.org>
+   Copyright (C) 2013-2018 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -35,7 +35,6 @@ using KContacts::Addressee;
 #include <QPushButton>
 #include <KGuiItem>
 #include <QVBoxLayout>
-#include <QDesktopServices>
 
 using namespace MessageViewer;
 
@@ -44,9 +43,8 @@ VCardViewer::VCardViewer(QWidget *parent, const QByteArray &vCard)
     , mAddresseeListIndex(0)
 {
     setWindowTitle(i18n("vCard Viewer"));
-    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close);
-    QVBoxLayout *mainLayout = new QVBoxLayout;
-    setLayout(mainLayout);
+    QVBoxLayout *mainLayout = new QVBoxLayout(this);
+    QDialogButtonBox *buttonBox = new QDialogButtonBox(QDialogButtonBox::Close, this);
     QPushButton *user1Button = new QPushButton;
     buttonBox->addButton(user1Button, QDialogButtonBox::ActionRole);
     mUser2Button = new QPushButton;
@@ -62,7 +60,7 @@ VCardViewer::VCardViewer(QWidget *parent, const QByteArray &vCard)
     KGuiItem::assign(mUser3Button, KGuiItem(i18n("&Previous Card")));
 
     mContactViewer = new KAddressBookGrantlee::GrantleeContactViewer(this);
-    Akonadi::ContactDefaultActions *actions = new Akonadi::ContactDefaultActions( this );
+    Akonadi::ContactDefaultActions *actions = new Akonadi::ContactDefaultActions(this);
     actions->connectToView(mContactViewer);
 
     mContactViewer->setForceDisableQRCode(true);
@@ -98,7 +96,7 @@ VCardViewer::~VCardViewer()
 
 void VCardViewer::readConfig()
 {
-    KConfigGroup group(MessageViewer::MessageViewerSettings::self()->config(), "VCardViewer");
+    KConfigGroup group(KSharedConfig::openConfig(), "VCardViewer");
     const QSize size = group.readEntry("Size", QSize(300, 400));
     if (size.isValid()) {
         resize(size);
@@ -107,7 +105,7 @@ void VCardViewer::readConfig()
 
 void VCardViewer::writeConfig()
 {
-    KConfigGroup group(MessageViewer::MessageViewerSettings::self()->config(), "VCardViewer");
+    KConfigGroup group(KSharedConfig::openConfig(), "VCardViewer");
     group.writeEntry("Size", size());
     group.sync();
 }
